<?php
/**
 * Buzz Agency Metabox
 *
 * @package buz-agency
 */
function buzz_agency_add_sidebar_layout_box() {
    add_meta_box(
        'buzz_agency_sidebar_layout', // $id
        esc_html__( 'Sidebar Layout','buzz-agency' ),
        'buzz_agency_sidebar_layout_callback', // $callback
        array( 'page','post'),
        'normal', // $context
        'high' // $priority
    ); 
}
add_action('add_meta_boxes', 'buzz_agency_add_sidebar_layout_box');

$buzz_agency_sidebar_layout = array(

    'left-sidebar' => array(
        'value'     => 'left-sidebar',
        'label'     => esc_html__( 'Left sidebar', 'buzz-agency' ),
        'thumbnail' => esc_url( get_template_directory_uri() ) . '/inc/images/sidebar-left.png'
    ), 
    'right-sidebar' => array(
        'value' => 'right-sidebar',
        'label' => esc_html__( 'Right sidebar (default)', 'buzz-agency' ),
        'thumbnail' => esc_url( get_template_directory_uri() ) . '/inc/images/sidebar-right.png'
    ),
    'both-sidebar' => array(
        'value'     => 'both-sidebar',
        'label'     => esc_html__( 'Both Sidebar', 'buzz-agency' ),
        'thumbnail' => esc_url( get_template_directory_uri() ) . '/inc/images/sidebar-both.png'
    ),
    
    'no-sidebar' => array(
        'value'     => 'no-sidebar',
        'label'     => esc_html__( 'No sidebar', 'buzz-agency' ),
        'thumbnail' => esc_url( get_template_directory_uri() ) . '/inc/images/sidebar-no.png'
    )   

);
// Sidebar layout 
function buzz_agency_sidebar_layout_callback(){ 
    global $post , $buzz_agency_sidebar_layout;
    wp_nonce_field( basename( __FILE__ ), 'buzz_agency_sidebar_layout_nonce' ); 
    ?>
    <table class="form-table">
        <tr>
            <td colspan="4"><em class="f13"><?php echo esc_html__('Choose Sidebar Template','buzz-agency');?></em></td>
        </tr>

        <tr>
            <td>
                <?php  
                foreach($buzz_agency_sidebar_layout as $field){  
                    $buzz_agency_sidebar_metalayout = get_post_meta( $post->ID, 'buzz_agency_sidebar_layout', true ); ?>
                    <div class="radio-image-wrapper" style="float:left; margin-right:30px;">
                        <label class="description">
                         <span><img src="<?php echo esc_url( $field['thumbnail'] ); ?>" /></span></br>
                         <input type="radio" name="buzz_agency_sidebar_layout" value="<?php echo esc_attr($field['value']); ?>" <?php checked( $field['value'], $buzz_agency_sidebar_metalayout ); if(empty($buzz_agency_sidebar_metalayout) && $field['value']=='right-sidebar'){ echo "checked='checked'";} ?>/>&nbsp;<?php echo esc_html($field['label']); ?>
                        </label>
                    </div>
                <?php } // end foreach 
                ?>
                <div class="clear"></div>
            </td>
        </tr>
    </table>
    
<?php } 

//==========================================================================================================//

/**
 * save the custom metabox data
 * @hooked to save_post hook
 */
function buzz_agency_save_sidebar_layout( $post_id ) { 
    
    global $buzz_agency_sidebar_layout, $post; 
    // Verify the nonce before proceeding.
    if ( !isset( $_POST[ 'buzz_agency_sidebar_layout_nonce' ] ) || !wp_verify_nonce( sanitize_key($_POST[ 'buzz_agency_sidebar_layout_nonce' ]), basename( __FILE__ ) ) )
        return;
    // Stop WP from clearing custom fields on autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE)  
        return;
    
    if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type']) {  
        if (!current_user_can( 'edit_page', $post_id ) )  
            return $post_id;  
    } elseif (!current_user_can( 'edit_post', $post_id ) ) {  
        return $post_id;  
    }  
    
    foreach ($buzz_agency_sidebar_layout as $field) {  
        //Execute this saving function
        $old = get_post_meta( $post_id, 'buzz_agency_sidebar_layout', true); 
        $new = sanitize_text_field( wp_unslash( $_POST['buzz_agency_sidebar_layout'] ) );
        if ($new && $new != $old) {  
            update_post_meta($post_id, 'buzz_agency_sidebar_layout', $new);  
        } elseif ('' == $new && $old) {  
            delete_post_meta($post_id,'buzz_agency_sidebar_layout', $old);  
        } 
     } // end foreach   
 }
 
 add_action('save_post', 'buzz_agency_save_sidebar_layout');
